"use client"

import { useState } from "react"
import Link from "next/link"
import { ChevronDown, ChevronRight, Info, ArrowRight } from "lucide-react"
import NavBar from "@/components/nav-bar"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Accordion, AccordionContent, AccordionItem, AccordionTrigger } from "@/components/ui/accordion"
import { Alert, AlertDescription } from "@/components/ui/alert"
import { simulationLevels } from "@/data/simulations"

// Exemple de questions pour la démonstration
const exampleQuestions = [
  {
    id: "q1",
    question: "Quelle est la vitesse maximale autorisée en agglomération ?",
    explanation: "En agglomération, la vitesse est limitée à 50 km/h sauf indication contraire.",
  },
  {
    id: "q2",
    question: "Que signifie un feu orange clignotant ?",
    explanation:
      "Un feu orange clignotant indique un danger particulier. Vous pouvez passer mais avec une prudence accrue.",
  },
  {
    id: "q3",
    question: "Quand le port de la ceinture de sécurité n'est-il pas obligatoire ?",
    explanation:
      "Le port de la ceinture est obligatoire sauf pour les personnes disposant d'un certificat médical d'exemption, les conducteurs en marche arrière, et certains professionnels lors de manœuvres à faible allure.",
  },
]

export default function SimulationsPage() {
  const [expandedExplanations, setExpandedExplanations] = useState<Record<string, boolean>>({})

  const toggleExplanation = (questionId: string) => {
    setExpandedExplanations((prev) => ({
      ...prev,
      [questionId]: !prev[questionId],
    }))
  }

  return (
    <div className="min-h-screen bg-gray-50">
 

      {/* En-tête de la page */}
      <div className="bg-gradient-to-r from-[#3d53b6] to-[#1da7f3] py-12 text-white">
        <div className="container mx-auto px-4">
          <h1 className="text-4xl font-bold text-center mb-4">Simulations d'Examens</h1>
          <p className="text-lg text-center max-w-3xl mx-auto">
            Préparez-vous efficacement à l'examen du code de la route avec nos simulations adaptées à tous les niveaux.
            Choisissez parmi différentes catégories pour progresser à votre rythme.
          </p>
        </div>
      </div>

      {/* Contenu principal */}
      <div className="container mx-auto px-4 py-12">
        {/* Explication */}
        <div className="mb-12 bg-white rounded-lg shadow-md p-6 border border-gray-200">
          <h2 className="text-2xl font-semibold mb-4 text-gray-800">Comment fonctionnent les simulations ?</h2>
          <div className="grid md:grid-cols-3 gap-6">
            <div className="flex flex-col items-center text-center p-4">
              <div className="w-16 h-16 rounded-full bg-blue-100 flex items-center justify-center mb-4">
                <span className="text-2xl">1</span>
              </div>
              <h3 className="font-medium text-lg mb-2">Choisissez votre niveau</h3>
              <p className="text-gray-600">
                Sélectionnez le niveau qui correspond à votre expérience et vos besoins d'apprentissage.
              </p>
            </div>
            <div className="flex flex-col items-center text-center p-4">
              <div className="w-16 h-16 rounded-full bg-blue-100 flex items-center justify-center mb-4">
                <span className="text-2xl">2</span>
              </div>
              <h3 className="font-medium text-lg mb-2">Répondez aux questions</h3>
              <p className="text-gray-600">
                Prenez votre temps pour répondre aux questions dans les conditions similaires à l'examen.
              </p>
            </div>
            <div className="flex flex-col items-center text-center p-4">
              <div className="w-16 h-16 rounded-full bg-blue-100 flex items-center justify-center mb-4">
                <span className="text-2xl">3</span>
              </div>
              <h3 className="font-medium text-lg mb-2">Analysez vos résultats</h3>
              <p className="text-gray-600">
                Consultez les explications détaillées pour comprendre vos erreurs et progresser.
              </p>
            </div>
          </div>
        </div>

        {/* Alerte d'information */}
        <Alert className="mb-8 border-[#1da7f3] bg-[#1da7f3]/10">
          <Info className="h-5 w-5 text-[#1da7f3]" />
          <AlertDescription className="ml-2">
            Nos simulations sont régulièrement mises à jour pour refléter les dernières modifications du code de la
            route.
          </AlertDescription>
        </Alert>

        {/* Niveaux de simulation */}
        <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-6 mb-12">
          {simulationLevels.map((level) => (
            <Card key={level.id} className={`border-2 transition-all duration-300 ${level.color}`}>
              <CardHeader className="pb-3">
                <div className="flex justify-between items-start">
                  <div>
                    <CardTitle className="text-xl font-bold flex items-center">
                      <span className="mr-2">{level.title}</span>
                      <span className="text-2xl">{level.icon}</span>
                    </CardTitle>
                    <CardDescription className="mt-2">{level.description}</CardDescription>
                  </div>
                </div>
              </CardHeader>
              <CardContent>
                <div className="flex flex-col space-y-2 text-sm">
                  <div className="flex justify-between">
                    <span className="text-gray-500">Simulations disponibles:</span>
                    <span className="font-medium">{level.count}</span>
                  </div>
                  <div className="flex justify-between">
                    <span className="text-gray-500">Questions par simulation:</span>
                    <span className="font-medium">{level.questions}</span>
                  </div>
                  <div className="flex justify-between">
                    <span className="text-gray-500">Durée moyenne:</span>
                    <span className="font-medium">{level.duration}</span>
                  </div>
                </div>
              </CardContent>
              <CardFooter>
                <Link href={`/simulations/${level.id}`} passHref>
                  <Button className={`w-full ${level.buttonColor} text-white`}>
                    Commencer <ArrowRight className="ml-2 h-4 w-4" />
                  </Button>
                </Link>
              </CardFooter>
            </Card>
          ))}
        </div>

        {/* Exemple de questions avec explications */}
        <div className="bg-white rounded-lg shadow-md p-6 border border-gray-200 mb-12">
          <h2 className="text-2xl font-semibold mb-6 text-gray-800">Exemple de questions</h2>
          <div className="space-y-6">
            {exampleQuestions.map((q) => (
              <div key={q.id} className="border border-gray-200 rounded-lg p-4">
                <div className="flex justify-between items-start">
                  <h3 className="font-medium text-lg mb-2">{q.question}</h3>
                  <button
                    onClick={() => toggleExplanation(q.id)}
                    className="text-[#3d53b6] hover:text-[#1da7f3] flex items-center text-sm font-medium"
                  >
                    {expandedExplanations[q.id] ? (
                      <>
                        Masquer l'explication <ChevronDown className="ml-1 h-4 w-4" />
                      </>
                    ) : (
                      <>
                        Voir l'explication <ChevronRight className="ml-1 h-4 w-4" />
                      </>
                    )}
                  </button>
                </div>

                {expandedExplanations[q.id] && (
                  <div className="mt-3 p-3 bg-gray-50 rounded-md border-l-4 border-[#1da7f3]">
                    <p className="text-gray-700">{q.explanation}</p>
                  </div>
                )}
              </div>
            ))}
          </div>
        </div>

        {/* FAQ */}
        <div className="bg-white rounded-lg shadow-md p-6 border border-gray-200">
          <h2 className="text-2xl font-semibold mb-6 text-gray-800">Questions fréquentes</h2>
          <Accordion type="single" collapsible className="w-full">
            <AccordionItem value="item-1">
              <AccordionTrigger>Comment choisir le niveau qui me convient ?</AccordionTrigger>
              <AccordionContent>
                Si vous débutez votre apprentissage, commencez par le niveau débutant. Si vous avez déjà des
                connaissances, essayez le niveau intermédiaire. Vous pouvez progresser vers les niveaux supérieurs au
                fur et à mesure que vous vous sentez plus à l'aise avec les questions.
              </AccordionContent>
            </AccordionItem>
            <AccordionItem value="item-2">
              <AccordionTrigger>Les simulations sont-elles chronométrées ?</AccordionTrigger>
              <AccordionContent>
                Oui, toutes nos simulations sont chronométrées pour reproduire les conditions réelles de l'examen. Vous
                disposerez généralement de 30 à 40 secondes par question selon le niveau de difficulté.
              </AccordionContent>
            </AccordionItem>
            <AccordionItem value="item-3">
              <AccordionTrigger>Puis-je reprendre une simulation plus tard ?</AccordionTrigger>
              <AccordionContent>
                Non, une fois commencée, une simulation doit être terminée. Cependant, vous pouvez toujours recommencer
                la même simulation ultérieurement pour vous entraîner à nouveau.
              </AccordionContent>
            </AccordionItem>
            <AccordionItem value="item-4">
              <AccordionTrigger>Comment fonctionne l'entraînement personnalisé ?</AccordionTrigger>
              <AccordionContent>
                L'entraînement personnalisé vous permet de sélectionner les thèmes spécifiques sur lesquels vous
                souhaitez vous concentrer. Vous pouvez également choisir le nombre de questions et la durée de la
                simulation.
              </AccordionContent>
            </AccordionItem>
          </Accordion>
        </div>
      </div>
    </div>
  )
}
